/*
 * SWE Ereigniskalender - Version 2
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * 
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49-341-49067-0
 * Fax: +49-341-49067-15
 * E-Mail: info@bitctrl.de
 */

package de.bsvrz.vew.ereigniskal.ereigniskal;

import de.bsvrz.dav.daf.main.ClientDavInterface;
import de.bsvrz.dav.daf.main.config.ConfigurationObject;
import de.bsvrz.dav.daf.main.config.DataModel;
import de.bsvrz.sys.funclib.application.StandardApplication;
import de.bsvrz.sys.funclib.application.StandardApplicationRunner;
import de.bsvrz.sys.funclib.commandLineArgs.ArgumentList;
import de.bsvrz.vew.ereigniskal.module.AnfrageHandler;
import de.bsvrz.vew.ereigniskal.module.EreignisVerwaltung;

/**
 * Hauptklasse der Anwendung/SWE Ereigniskalender
 * 
 * @author BitCtrl Systems GmbH, Uwe Peuker
 */
public class EreignisKalender implements StandardApplication {

    /** Verbindung zum Datenverteiler. */
    private ClientDavInterface davVerbindung;

    /** String fuer den Kalender. */
    private String kalenderPid;

    /**
     * Überschriebene Methode von StandardApplication, die die speziellen
     * Startparameter auswertet.<br>
     * Die Liste der Konfigurationsbereiche wird durch Aufspaltung des
     * übergebenen Strings erstellt und die speziellen Startparameter werden in
     * die Log-Datei eingetragen.
     * 
     * @param argumentList
     *            siehe
     *            sys.funclib.application.StandardApplication#parseArguments(sys.funclib.ArgumentList)
     */
    @Override
    public void parseArguments(ArgumentList argumentList) throws Exception {

        if (argumentList.hasArgument("-kalender")) {
            kalenderPid = argumentList.fetchArgument("-kalender=").asString().trim();
        }

        argumentList.fetchUnusedArguments();
    }

    /**
     * Überschriebene Methode von StandardApplication, die die Initialisierung
     * durchführt.<br>
     * Entsprechend dem Argument -layer wird die entsprechende Methode
     * aufgerufen und danach die Log-Datei geschlossen.<br>
     * 
     * @param connection
     *            siehe
     *            sys.funclib.application.StandardApplication#initialize(stauma.dav.clientside.ClientDavInterface)
     */
    @Override
    public void initialize(ClientDavInterface connection) throws Exception {

        davVerbindung = connection;
        DataModel datenmodell = davVerbindung.getDataModel();

        ConfigurationObject kalenderObj;
        if (kalenderPid == null) {
            kalenderObj = davVerbindung.getLocalConfigurationAuthority();
        } else {
            kalenderObj = (ConfigurationObject) datenmodell.getObject(kalenderPid);
        }

        if (kalenderObj == null || !kalenderObj.isOfType("typ.kalender")) {
            final String errorMessage = "Das Object " + kalenderObj
                    + " ist kein Kalender (typ.kalender). Applikation kann nicht gestartet werden.";
            davVerbindung.disconnect(true, errorMessage);
            System.exit(0);
        }

        EreignisVerwaltung ereignisVerwaltung = new EreignisVerwaltung(davVerbindung, kalenderObj);
        AnfrageHandler anfrageHandler = new AnfrageHandler();
        anfrageHandler.run(davVerbindung, kalenderObj, ereignisVerwaltung);
    }

    /**
     * Programmeinstieg.<br>
     * 
     * @param arguments
     *            Kommandozeilenargumente
     */
    public static void main(String[] arguments) {
        StandardApplicationRunner.run(new EreignisKalender(), arguments);
    }
}
